==> estateplat-common-1.2.3-20180308.015314-39-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwLjz.java <==
package cn.gtmap.estateplat.model.server.core;

import org.springframework.data.annotation.Id;

import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2015/5/7.
 */
@Table(name = "djsj_fw_ljz")
public class DjsjFwLjz {
    @Id
    private String fwDcbIndex;
    private String fwXmxxIndex;
    private String bdcdyfwlx;
    private String bdcdyh;
    private String lszd;
    private String dh;
    private String fwmc;
    private String zldz;

    private String fwjg;
    private int fwcs;
    private String bz;
    private String fwyt;
    private Date jgrq;
    private String zrzh;
    private double ycjzmj;
    private double ycdxmj;
    private double ycqtmj;

    private double scjzmj;
    private double scdxmj;
    private double scqtmj;

    private String xmmc;
    private int zts;
    private String bdczt;//不动产状态
    private Double zzdmj;//幢占地面积
    private String fwKfxmIndex;//开发项目主键
    private String ljzh;//逻辑幢号

    public Double getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(double zzdmj) {
        this.zzdmj = zzdmj;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getFwXmxxIndex() {
        return fwXmxxIndex;
    }

    public void setFwXmxxIndex(String fwXmxxIndex) {
        this.fwXmxxIndex = fwXmxxIndex;
    }

    public String getBdcdyfwlx() {
        return bdcdyfwlx;
    }

    public void setBdcdyfwlx(String bdcdyfwlx) {
        this.bdcdyfwlx = bdcdyfwlx;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public String getFwmc() {
        return fwmc;
    }

    public void setFwmc(String fwmc) {
        this.fwmc = fwmc;
    }

    public String getZldz() {
        return zldz;
    }

    public void setZldz(String zldz) {
        this.zldz = zldz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public int getFwcs() {
        return fwcs;
    }

    public void setFwcs(int fwcs) {
        this.fwcs = fwcs;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public Date getJgrq() {
        return jgrq;
    }

    public void setJgrq(Date jgrq) {
        this.jgrq = jgrq;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public double getYcdxmj() {
        return ycdxmj;
    }

    public void setYcdxmj(double ycdxmj) {
        this.ycdxmj = ycdxmj;
    }

    public double getYcqtmj() {
        return ycqtmj;
    }

    public void setYcqtmj(double ycqtmj) {
        this.ycqtmj = ycqtmj;
    }

    public double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public double getScdxmj() {
        return scdxmj;
    }

    public void setScdxmj(double scdxmj) {
        this.scdxmj = scdxmj;
    }

    public double getScqtmj() {
        return scqtmj;
    }

    public void setScqtmj(double scqtmj) {
        this.scqtmj = scqtmj;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public int getZts() {
        return zts;
    }

    public void setZts(int zts) {
        this.zts = zts;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }

    public void setZzdmj(Double zzdmj) {
        this.zzdmj = zzdmj;
    }

    public String getFwKfxmIndex() {
        return fwKfxmIndex;
    }

    public void setFwKfxmIndex(String fwKfxmIndex) {
        this.fwKfxmIndex = fwKfxmIndex;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }
}

==> estateplat-common-1.2.4-20181105.022112-48-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwLjz.java <==
package cn.gtmap.estateplat.model.server.core;

import org.springframework.data.annotation.Id;

import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2015/5/7.
 */
@Table(name = "djsj_fw_ljz")
public class DjsjFwLjz {
    @Id
    private String fwDcbIndex;
    private String fwXmxxIndex;
    private String bdcdyfwlx;
    private String bdcdyh;
    private String lszd;
    private String dh;
    private String fwmc;
    private String zldz;

    private String fwjg;
    private int fwcs;
    private String bz;
    private String fwyt;
    private Date jgrq;
    private String zrzh;
    private double ycjzmj;
    private double ycdxmj;
    private double ycqtmj;

    private double scjzmj;
    private double scdxmj;
    private double scqtmj;

    private String xmmc;
    private int zts;
    private String bdczt;//不动产状态
    private Double zzdmj;//幢占地面积
    private String fwKfxmIndex;//开发项目主键
    private String ljzh;//逻辑幢号
    private Integer jznd;//建筑年代

    public Double getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(double zzdmj) {
        this.zzdmj = zzdmj;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getFwXmxxIndex() {
        return fwXmxxIndex;
    }

    public void setFwXmxxIndex(String fwXmxxIndex) {
        this.fwXmxxIndex = fwXmxxIndex;
    }

    public String getBdcdyfwlx() {
        return bdcdyfwlx;
    }

    public void setBdcdyfwlx(String bdcdyfwlx) {
        this.bdcdyfwlx = bdcdyfwlx;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public String getFwmc() {
        return fwmc;
    }

    public void setFwmc(String fwmc) {
        this.fwmc = fwmc;
    }

    public String getZldz() {
        return zldz;
    }

    public void setZldz(String zldz) {
        this.zldz = zldz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public int getFwcs() {
        return fwcs;
    }

    public void setFwcs(int fwcs) {
        this.fwcs = fwcs;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public Date getJgrq() {
        return jgrq;
    }

    public void setJgrq(Date jgrq) {
        this.jgrq = jgrq;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public double getYcdxmj() {
        return ycdxmj;
    }

    public void setYcdxmj(double ycdxmj) {
        this.ycdxmj = ycdxmj;
    }

    public double getYcqtmj() {
        return ycqtmj;
    }

    public void setYcqtmj(double ycqtmj) {
        this.ycqtmj = ycqtmj;
    }

    public double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public double getScdxmj() {
        return scdxmj;
    }

    public void setScdxmj(double scdxmj) {
        this.scdxmj = scdxmj;
    }

    public double getScqtmj() {
        return scqtmj;
    }

    public void setScqtmj(double scqtmj) {
        this.scqtmj = scqtmj;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public int getZts() {
        return zts;
    }

    public void setZts(int zts) {
        this.zts = zts;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }

    public void setZzdmj(Double zzdmj) {
        this.zzdmj = zzdmj;
    }

    public String getFwKfxmIndex() {
        return fwKfxmIndex;
    }

    public void setFwKfxmIndex(String fwKfxmIndex) {
        this.fwKfxmIndex = fwKfxmIndex;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }

    public Integer getJznd() {
        return jznd;
    }

    public void setJznd(Integer jznd) {
        this.jznd = jznd;
    }
}
